diff --git src/wp-admin/includes/network.php src/wp-admin/includes/network.php
index fef6b66..1b7dac9 100644
--- src/wp-admin/includes/network.php
+++ src/wp-admin/includes/network.php
@@ -335,6 +335,7 @@ function network_step1( $errors = false ) {
  */
 function network_step2( $errors = false ) {
 	global $wpdb;
+	global $is_nginx;
 
 	$hostname          = get_clean_basedomain();
 	$slashed_home      = trailingslashit( get_option( 'home' ) );
@@ -548,7 +549,16 @@ define('BLOG_ID_CURRENT_SITE', 1);
 		</textarea></li>
 		</ol>
 
-	<?php else : // end iis7_supports_permalinks(). construct an htaccess file instead:
+	<?php elseif($is_nginx): // end iis7_supports_permalinks(). check if server is nginx and print link to Codex:
+		$section = $subdomain_install ? 'WordPress_Multisite_subdomains_rules' : 'WordPress_Multisite_Subdirectory_rules';
+		echo  '<li><p>';
+		printf(
+			__('It seems your network is running with NGINX webserver. Please, visit %1$s to get details about further configuration'),
+			'<a href="https://codex.wordpress.org/Nginx#'.$section.'" target="_blank">https://codex.wordpress.org/Nginx#'.$section.'</a>'
+		);
+		echo '</p>'
+		?>
+	<?php else : // end of nginx variant, construct .htaccess
 
 		$ms_files_rewriting = '';
 		if ( is_multisite() && get_site_option( 'ms_files_rewriting' ) ) {
